AddAttributesActivity class

An activity that adds other attributes based on existing attributes in the message.

Constructors

AddAttributesActivity({required Map<String, String> attributes, required String name, String? next})
AddAttributesActivity.fromJson(Map<String, dynamic> json)
factory

Properties

attributes → Map<String, String>
A list of 1-50 AttributeNameMapping objects that map an existing attribute to a new attribute.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the addAttributes activity.
final
next → String?
The next activity in the pipeline.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited