BatchPutMessageErrorEntry class

Contains informations about errors.

Constructors

BatchPutMessageErrorEntry({String? errorCode, String? errorMessage, String? messageId})
BatchPutMessageErrorEntry.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → String?
The code associated with the error.
final
errorMessage → String?
The message associated with the error.
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → String?
The ID of the message that caused the error. See the value corresponding to the messageId key in the message object.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited