Channel class

A collection of data from an MQTT topic. Channels archive the raw, unprocessed messages before publishing the data to a pipeline.

Constructors

Channel({String? arn, DateTime? creationTime, DateTime? lastMessageArrivalTime, DateTime? lastUpdateTime, String? name, RetentionPeriod? retentionPeriod, ChannelStatus? status, ChannelStorage? storage})
Channel.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The ARN of the channel.
final
creationTime → DateTime?
When the channel was created.
final
hashCode → int
The hash code for this object.
no setterinherited
lastMessageArrivalTime → DateTime?
The last time when a new message arrived in the channel.
final
lastUpdateTime → DateTime?
When the channel was last updated.
final
name → String?
The name of the channel.
final
retentionPeriod → RetentionPeriod?
How long, in days, message data is kept for the channel.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ChannelStatus?
The status of the channel.
final
storage → ChannelStorage?
Where channel data is stored. You can choose one of serviceManagedS3 or customerManagedS3 storage. If not specified, the default is serviceManagedS3. You cannot change this storage option after the channel is created.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited