ChannelActivity class

The activity that determines the source of the messages to be processed.

Constructors

ChannelActivity({required String channelName, required String name, String? next})
ChannelActivity.fromJson(Map<String, dynamic> json)
factory

Properties

channelName → String
The name of the channel from which the messages are processed.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the channel activity.
final
next → String?
The next activity in the pipeline.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited