ChannelSummary class

A summary of information about a channel.

Constructors

ChannelSummary({String? channelName, ChannelStorageSummary? channelStorage, DateTime? creationTime, DateTime? lastMessageArrivalTime, DateTime? lastUpdateTime, ChannelStatus? status})
ChannelSummary.fromJson(Map<String, dynamic> json)
factory

Properties

channelName → String?
The name of the channel.
final
channelStorage → ChannelStorageSummary?
Where channel data is stored.
final
creationTime → DateTime?
When the channel was created.
final
hashCode → int
The hash code for this object.
no setterinherited
lastMessageArrivalTime → DateTime?
The last time when a new message arrived in the channel.
final
lastUpdateTime → DateTime?
The last time the channel was updated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ChannelStatus?
The status of the channel.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited