Column class

Contains information about a column that stores your data.

Constructors

Column({required String name, required String type})
Column.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the column.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of data. For more information about the supported data types, see Common data types in the AWS Glue Developer Guide.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited