CreateChannelResponse class

Constructors

CreateChannelResponse({String? channelArn, String? channelName, RetentionPeriod? retentionPeriod})
CreateChannelResponse.fromJson(Map<String, dynamic> json)
factory

Properties

channelArn → String?
The ARN of the channel.
final
channelName → String?
The name of the channel.
final
hashCode → int
The hash code for this object.
no setterinherited
retentionPeriod → RetentionPeriod?
How long, in days, message data is kept for the channel.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited