CreateDatasetResponse class

Constructors

CreateDatasetResponse({String? datasetArn, String? datasetName, RetentionPeriod? retentionPeriod})
CreateDatasetResponse.fromJson(Map<String, dynamic> json)
factory

Properties

datasetArn → String?
The ARN of the dataset.
final
datasetName → String?
The name of the dataset.
final
hashCode → int
The hash code for this object.
no setterinherited
retentionPeriod → RetentionPeriod?
How long, in days, dataset contents are kept for the dataset.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited