CreateDatastoreResponse class

Constructors

CreateDatastoreResponse({String? datastoreArn, String? datastoreName, RetentionPeriod? retentionPeriod})
CreateDatastoreResponse.fromJson(Map<String, dynamic> json)
factory

Properties

datastoreArn → String?
The ARN of the data store.
final
datastoreName → String?
The name of the data store.
final
hashCode → int
The hash code for this object.
no setterinherited
retentionPeriod → RetentionPeriod?
How long, in days, message data is kept for the data store.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited