CustomerManagedDatastoreS3Storage class

Use this to store data store data in an S3 bucket that you manage. When customer-managed storage is selected, the retentionPeriod parameter is ignored. You cannot change the choice of service-managed or customer-managed S3 storage after the data store is created.

Constructors

CustomerManagedDatastoreS3Storage({required String bucket, required String roleArn, String? keyPrefix})
CustomerManagedDatastoreS3Storage.fromJson(Map<String, dynamic> json)
factory

Properties

bucket → String
The name of the S3 bucket in which data store data is stored.
final
hashCode → int
The hash code for this object.
no setterinherited
keyPrefix → String?
Optional. The prefix used to create the keys of the data store data objects. Each object in an S3 bucket has a key that is its unique identifier in the bucket. Each object in a bucket has exactly one key. The prefix must end with a forward slash (/).
final
roleArn → String
The ARN of the role that grants AWS IoT Analytics permission to interact with your Amazon S3 resources.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited