Dataset class

Information about a data set.

Constructors

Dataset({List<DatasetAction>? actions, String? arn, List<DatasetContentDeliveryRule>? contentDeliveryRules, DateTime? creationTime, DateTime? lastUpdateTime, List<LateDataRule>? lateDataRules, String? name, RetentionPeriod? retentionPeriod, DatasetStatus? status, List<DatasetTrigger>? triggers, VersioningConfiguration? versioningConfiguration})
Dataset.fromJson(Map<String, dynamic> json)
factory

Properties

actions → List<DatasetAction>?
The DatasetAction objects that automatically create the data set contents.
final
arn → String?
The ARN of the data set.
final
contentDeliveryRules → List<DatasetContentDeliveryRule>?
When dataset contents are created they are delivered to destinations specified here.
final
creationTime → DateTime?
When the data set was created.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdateTime → DateTime?
The last time the data set was updated.
final
lateDataRules → List<LateDataRule>?
A list of data rules that send notifications to Amazon CloudWatch, when data arrives late. To specify lateDataRules, the dataset must use a DeltaTimer filter.
final
name → String?
The name of the data set.
final
retentionPeriod → RetentionPeriod?
Optional. How long, in days, message data is kept for the data set.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → DatasetStatus?
The status of the data set.
final
triggers → List<DatasetTrigger>?
The DatasetTrigger objects that specify when the data set is automatically updated.
final
versioningConfiguration → VersioningConfiguration?
Optional. How many versions of dataset contents are kept. If not specified or set to null, only the latest version plus the latest succeeded version (if they are different) are kept for the time period specified by the retentionPeriod parameter. For more information, see Keeping Multiple Versions of AWS IoT Analytics Data Sets in the AWS IoT Analytics User Guide.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited