DatasetAction class

A DatasetAction object that specifies how data set contents are automatically created.

Constructors

DatasetAction({String? actionName, ContainerDatasetAction? containerAction, SqlQueryDatasetAction? queryAction})
DatasetAction.fromJson(Map<String, dynamic> json)
factory

Properties

actionName → String?
The name of the data set action by which data set contents are automatically created.
final
containerAction → ContainerDatasetAction?
Information that allows the system to run a containerized application to create the dataset contents. The application must be in a Docker container along with any required support libraries.
final
hashCode → int
The hash code for this object.
no setterinherited
queryAction → SqlQueryDatasetAction?
An SqlQueryDatasetAction object that uses an SQL query to automatically create data set contents.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited