DatasetContentDeliveryRule class

When dataset contents are created, they are delivered to destination specified here.

Constructors

DatasetContentDeliveryRule({required DatasetContentDeliveryDestination destination, String? entryName})
DatasetContentDeliveryRule.fromJson(Map<String, dynamic> json)
factory

Properties

destination → DatasetContentDeliveryDestination
The destination to which dataset contents are delivered.
final
entryName → String?
The name of the dataset content delivery rules entry.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited