DatasetContentStatus class

The state of the data set contents and the reason they are in this state.

Constructors

DatasetContentStatus({String? reason, DatasetContentState? state})
DatasetContentStatus.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason → String?
The reason the data set contents are in this state.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → DatasetContentState?
The state of the data set contents. Can be one of READY, CREATING, SUCCEEDED, or FAILED.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited