DatasetContentSummary class

Summary information about dataset contents.

Constructors

DatasetContentSummary({DateTime? completionTime, DateTime? creationTime, DateTime? scheduleTime, DatasetContentStatus? status, String? version})
DatasetContentSummary.fromJson(Map<String, dynamic> json)
factory

Properties

completionTime → DateTime?
The time the dataset content status was updated to SUCCEEDED or FAILED.
final
creationTime → DateTime?
The actual time the creation of the dataset contents was started.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduleTime → DateTime?
The time the creation of the dataset contents was scheduled to start.
final
status → DatasetContentStatus?
The status of the data set contents.
final
version → String?
The version of the dataset contents.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited