DatasetEntry class

The reference to a data set entry.

Constructors

DatasetEntry({String? dataURI, String? entryName})
DatasetEntry.fromJson(Map<String, dynamic> json)
factory

Properties

dataURI → String?
The presigned URI of the data set item.
final
entryName → String?
The name of the data set item.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited