DatasetSummary class

A summary of information about a data set.

Constructors

DatasetSummary({List<DatasetActionSummary>? actions, DateTime? creationTime, String? datasetName, DateTime? lastUpdateTime, DatasetStatus? status, List<DatasetTrigger>? triggers})
DatasetSummary.fromJson(Map<String, dynamic> json)
factory

Properties

actions → List<DatasetActionSummary>?
A list of DataActionSummary objects.
final
creationTime → DateTime?
The time the data set was created.
final
datasetName → String?
The name of the data set.
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdateTime → DateTime?
The last time the data set was updated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → DatasetStatus?
The status of the data set.
final
triggers → List<DatasetTrigger>?
A list of triggers. A trigger causes data set content to be populated at a specified time interval or when another data set is populated. The list of triggers can be empty or contain up to five DataSetTrigger objects
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited