DatasetTrigger class

The DatasetTrigger that specifies when the data set is automatically updated.

Constructors

DatasetTrigger({TriggeringDataset? dataset, Schedule? schedule})
DatasetTrigger.fromJson(Map<String, dynamic> json)
factory

Properties

dataset → TriggeringDataset?
The data set whose content creation triggers the creation of this data set's contents.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule → Schedule?
The Schedule when the trigger is initiated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited