DatastoreActivity class

The datastore activity that specifies where to store the processed data.

Constructors

DatastoreActivity({required String datastoreName, required String name})
DatastoreActivity.fromJson(Map<String, dynamic> json)
factory

Properties

datastoreName → String
The name of the data store where processed messages are stored.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the datastore activity.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited