DatastoreStatistics class

Statistical information about the data store.

Constructors

DatastoreStatistics({EstimatedResourceSize? size})
DatastoreStatistics.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → EstimatedResourceSize?
The estimated size of the data store.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited