DatastoreStorageSummary class

Where data store data is stored.

Properties

customerManagedS3 → CustomerManagedDatastoreS3StorageSummary?
Used to store data store data in an S3 bucket that you manage.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceManagedS3 → ServiceManagedDatastoreS3StorageSummary?
Used to store data store data in an S3 bucket managed by AWS IoT Analytics.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited