DatastoreSummary class

A summary of information about a data store.

Constructors

DatastoreSummary({DateTime? creationTime, String? datastoreName, DatastoreStorageSummary? datastoreStorage, FileFormatType? fileFormatType, DateTime? lastMessageArrivalTime, DateTime? lastUpdateTime, DatastoreStatus? status})
DatastoreSummary.fromJson(Map<String, dynamic> json)
factory

Properties

creationTime → DateTime?
When the data store was created.
final
datastoreName → String?
The name of the data store.
final
datastoreStorage → DatastoreStorageSummary?
Where data store data is stored.
final
fileFormatType → FileFormatType?
The file format of the data in the data store.
final
hashCode → int
The hash code for this object.
no setterinherited
lastMessageArrivalTime → DateTime?
The last time when a new message arrived in the data store.
final
lastUpdateTime → DateTime?
The last time the data store was updated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → DatastoreStatus?
The status of the data store.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited