DescribeChannelResponse class

Constructors

DescribeChannelResponse({Channel? channel, ChannelStatistics? statistics})
DescribeChannelResponse.fromJson(Map<String, dynamic> json)
factory

Properties

channel → Channel?
An object that contains information about the channel.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statistics → ChannelStatistics?
Statistics about the channel. Included if the includeStatistics parameter is set to true in the request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited