DescribeDatastoreResponse class

Constructors

DescribeDatastoreResponse({Datastore? datastore, DatastoreStatistics? statistics})
DescribeDatastoreResponse.fromJson(Map<String, dynamic> json)
factory

Properties

datastore → Datastore?
Information about the data store.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statistics → DatastoreStatistics?
Additional statistical information about the data store. Included if the includeStatistics parameter is set to true in the request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited