DeviceShadowEnrichActivity class

An activity that adds information from the AWS IoT Device Shadow service to a message.

Constructors

DeviceShadowEnrichActivity({required String attribute, required String name, required String roleArn, required String thingName, String? next})
DeviceShadowEnrichActivity.fromJson(Map<String, dynamic> json)
factory

Properties

attribute → String
The name of the attribute that is added to the message.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the deviceShadowEnrich activity.
final
next → String?
The next activity in the pipeline.
final
roleArn → String
The ARN of the role that allows access to the device's shadow.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thingName → String
The name of the IoT device whose shadow information is added to the message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited