EstimatedResourceSize class

The estimated size of the resource.

Constructors

EstimatedResourceSize({DateTime? estimatedOn, double? estimatedSizeInBytes})
EstimatedResourceSize.fromJson(Map<String, dynamic> json)
factory

Properties

estimatedOn → DateTime?
The time when the estimate of the size of the resource was made.
final
estimatedSizeInBytes → double?
The estimated size of the resource, in bytes.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited