FilterActivity class

An activity that filters a message based on its attributes.

Constructors

FilterActivity({required String filter, required String name, String? next})
FilterActivity.fromJson(Map<String, dynamic> json)
factory

Properties

filter → String
An expression that looks like a SQL WHERE clause that must return a Boolean value. Messages that satisfy the condition are passed to the next activity.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the filter activity.
final
next → String?
The next activity in the pipeline.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited