GetDatasetContentResponse class

Constructors

GetDatasetContentResponse({List<DatasetEntry>? entries, DatasetContentStatus? status, DateTime? timestamp})
GetDatasetContentResponse.fromJson(Map<String, dynamic> json)
factory

Properties

entries → List<DatasetEntry>?
A list of DatasetEntry objects.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → DatasetContentStatus?
The status of the data set content.
final
timestamp → DateTime?
The time when the request was made.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited