IotEventsDestinationConfiguration class

Configuration information for delivery of dataset contents to AWS IoT Events.

Constructors

IotEventsDestinationConfiguration({required String inputName, required String roleArn})
IotEventsDestinationConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputName → String
The name of the AWS IoT Events input to which dataset contents are delivered.
final
roleArn → String
The ARN of the role that grants AWS IoT Analytics permission to deliver dataset contents to an AWS IoT Events input.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited