ListChannelsResponse class

Constructors

ListChannelsResponse({List<ChannelSummary>? channelSummaries, String? nextToken})
ListChannelsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

channelSummaries → List<ChannelSummary>?
A list of ChannelSummary objects.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The token to retrieve the next set of results, or null if there are no more results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited