LoggingOptions class

Information about logging options.

Constructors

LoggingOptions({required bool enabled, required LoggingLevel level, required String roleArn})
LoggingOptions.fromJson(Map<String, dynamic> json)
factory

Properties

enabled → bool
If true, logging is enabled for AWS IoT Analytics.
final
hashCode → int
The hash code for this object.
no setterinherited
level → LoggingLevel
The logging level. Currently, only ERROR is supported.
final
roleArn → String
The ARN of the role that grants permission to AWS IoT Analytics to perform logging.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited