MathActivity class

An activity that computes an arithmetic expression using the message's attributes.

Constructors

MathActivity({required String attribute, required String math, required String name, String? next})
MathActivity.fromJson(Map<String, dynamic> json)
factory

Properties

attribute → String
The name of the attribute that contains the result of the math operation.
final
hashCode → int
The hash code for this object.
no setterinherited
math → String
An expression that uses one or more existing attributes and must return an integer value.
final
name → String
The name of the math activity.
final
next → String?
The next activity in the pipeline.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited