Message class

Information about a message.

Constructors

Message({required String messageId, required Uint8List payload})

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageId → String
The ID you want to assign to the message. Each messageId must be unique within each batch sent.
final
payload → Uint8List
The payload of the message. This can be a JSON string or a base64-encoded string representing binary data, in which case you must decode it by means of a pipeline activity.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited