QueryFilter class

Information that is used to filter message data, to segregate it according to the timeframe in which it arrives.

Constructors

QueryFilter({DeltaTime? deltaTime})
QueryFilter.fromJson(Map<String, dynamic> json)
factory

Properties

deltaTime → DeltaTime?
Used to limit data to that which has arrived since the last execution of the action.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited