ResourceConfiguration class

The configuration of the resource used to execute the containerAction.

Constructors

ResourceConfiguration({required ComputeType computeType, required int volumeSizeInGB})
ResourceConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

computeType → ComputeType
The type of the compute resource used to execute the containerAction. Possible values are: ACU_1 (vCPU=4, memory=16 GiB) or ACU_2 (vCPU=8, memory=32 GiB).
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volumeSizeInGB → int
The size, in GB, of the persistent storage available to the resource instance used to execute the containerAction (min: 1, max: 50).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited