RetentionPeriod class

How long, in days, message data is kept.

Constructors

RetentionPeriod({int? numberOfDays, bool? unlimited})
RetentionPeriod.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
numberOfDays → int?
The number of days that message data is kept. The unlimited parameter must be false.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unlimited → bool?
If true, message data is kept indefinitely.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited