RunPipelineActivityResponse class

Constructors

RunPipelineActivityResponse({String? logResult, List<Uint8List>? payloads})
RunPipelineActivityResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
logResult → String?
In case the pipeline activity fails, the log message that is generated.
final
payloads → List<Uint8List>?
The enriched or transformed sample message payloads as base64-encoded strings. (The results of running the pipeline activity on each input sample message payload, encoded in base64.)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited