S3DestinationConfiguration class

Configuration information for delivery of dataset contents to Amazon Simple Storage Service (Amazon S3).

Constructors

S3DestinationConfiguration({required String bucket, required String key, required String roleArn, GlueConfiguration? glueConfiguration})
S3DestinationConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

bucket → String
The name of the S3 bucket to which dataset contents are delivered.
final
glueConfiguration → GlueConfiguration?
Configuration information for coordination with AWS Glue, a fully managed extract, transform and load (ETL) service.
final
hashCode → int
The hash code for this object.
no setterinherited
key → String
The key of the dataset contents object in an S3 bucket. Each object has a key that is a unique identifier. Each object has exactly one key.
final
roleArn → String
The ARN of the role that grants AWS IoT Analytics permission to interact with your Amazon S3 and AWS Glue resources.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited