SampleChannelDataResponse class

Constructors

SampleChannelDataResponse({List<Uint8List>? payloads})
SampleChannelDataResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
payloads → List<Uint8List>?
The list of message samples. Each sample message is returned as a base64-encoded string.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited