SelectAttributesActivity class

Creates a new message using only the specified attributes from the original message.

Constructors

SelectAttributesActivity({required List<String> attributes, required String name, String? next})
SelectAttributesActivity.fromJson(Map<String, dynamic> json)
factory

Properties

attributes → List<String>
A list of the attributes to select from the message.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the selectAttributes activity.
final
next → String?
The next activity in the pipeline.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited