VersioningConfiguration class

Information about the versioning of dataset contents.

Constructors

VersioningConfiguration({int? maxVersions, bool? unlimited})
VersioningConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxVersions → int?
How many versions of dataset contents are kept. The unlimited parameter must be false.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unlimited → bool?
If true, unlimited versions of dataset contents are kept.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited